summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-05-17 01:36:13 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-05-17 01:36:13 +0000
commitded3b65a0dfd01a304e0b1c9f41c5d9fafc1d3f8 (patch)
tree9d6d2a77c39e986ffa86f8e094ec446deb3f742c /crawl-ref/source/religion.cc
parent408f0d9ba4e28730d1bb388f8ed2f771c9d45155 (diff)
downloadcrawl-ref-ded3b65a0dfd01a304e0b1c9f41c5d9fafc1d3f8.tar.gz
crawl-ref-ded3b65a0dfd01a304e0b1c9f41c5d9fafc1d3f8.zip
For TSO, change the "stabbing" conduct to an "unchivalrous attack"
conduct, and exercise it on every stabbing attempt, whether it succeeds or not (and also whether the player is berserk or not, since a berserk player trying to stab seems unchivalrous to me). git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@5093 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index fa118ea910..ff5e28e4b6 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -1893,7 +1893,7 @@ bool did_god_conduct( conduct_type thing_done, int level, bool known,
}
break;
- case DID_STABBING:
+ case DID_UNCHIVALRIC_ATTACK:
case DID_POISON:
if (you.religion == GOD_SHINING_ONE)
{
@@ -2373,11 +2373,11 @@ bool did_god_conduct( conduct_type thing_done, int level, bool known,
{
"",
"Necromancy", "Unholy", "Attack Holy", "Attack Neutral",
- "Attack Friend", "Friend Died", "Stab", "Poison", "Field Sacrifice",
- "Kill Living", "Kill Undead", "Kill Demon", "Kill Natural Evil",
- "Kill Mutator Or Rotter", "Kill Wizard", "Kill Priest",
- "Kill Holy", "Undead Slave Kill Living", "Servant Kill Living",
- "Servant Kill Undead", "Servant Kill Demon",
+ "Attack Friend", "Friend Died", "Unchivalric Attack", "Poison",
+ "Field Sacrifice", "Kill Living", "Kill Undead", "Kill Demon",
+ "Kill Natural Evil", "Kill Mutator Or Rotter", "Kill Wizard",
+ "Kill Priest", "Kill Holy", "Undead Slave Kill Living",
+ "Servant Kill Living", "Servant Kill Undead", "Servant Kill Demon",
"Servant Kill Natural Evil", "Servant Kill Holy", "Spell Memorise",
"Spell Cast", "Spell Practise", "Spell Nonutility", "Cards",
"Stimulants", "Drink Blood", "Cannibalism", "Eat Meat",
@@ -5356,9 +5356,9 @@ int piety_breakpoint(int i)
return breakpoints[i];
}
-// Returns true if the Shining One doesn't mind your stabbing this
-// creature.
-bool tso_stab_safe_monster(const actor *act)
+// Returns true if the Shining One doesn't mind your using unchivalric
+// attacks on this creature.
+bool tso_unchivalric_attack_safe_monster(const actor *act)
{
const mon_holy_type holy = act->holiness();
return (holy != MH_NATURAL && holy != MH_HOLY);